==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/uk.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Завдання",
    "Due yesterday" : "Вчора",
    "Due today" : "Сьогодні",
    "Due tomorrow" : "Завтра",
    "Due on" : "Термін",
    "Started yesterday" : "Розпочато вчора",
    "Starts today" : "Розпочато сьогодні",
    "Starts tomorrow" : "Розпочнеться завтра",
    "Started on" : "Розпочато",
    "Starts on" : "Починається",
    "[Remind me yesterday at ]HH:mm" : "[Нагадати мені вчора о ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Нагадати мені сьгодні о ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Нагадати мені завтра о ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Нагадати мені ]MMM DD, YYYY,[ о ]HH:mm",
    "Yesterday" : "Вчора",
    "Today" : "Сьогодні",
    "Tomorrow" : "Завтра",
    "in %s" : "в %s",
    "%s ago" : "%s тому",
    "seconds" : "секунд",
    "a minute" : "хвилину",
    "%d minutes" : "%d хвилин",
    "an hour" : "годину",
    "%d hours" : "%d годин",
    "a day" : "день",
    "%d days" : "%d днів",
    "a month" : "місяць",
    "%d months" : "%d місяців",
    "a year" : "рік",
    "%d years" : "%d років",
    "week" : "тиждень",
    "weeks" : "тижнів",
    "day" : "день",
    "days" : "днів",
    "hour" : "година",
    "hours" : "годин",
    "minute" : "хвилина",
    "minutes" : "хвилин",
    "second" : "другий",
    "before beginning" : "до початку",
    "after beginning" : "після початку",
    "before end" : "до кінця",
    "after end" : "після закінчення",
    "Comment" : "Коментар",
    "Add a comment" : "Додати коментар",
    "This will delete the Calendar \"%s\" and all of its entries." : "Це призведе до видалення Календаря \"%s\" і всіх його записів.",
    "The name \"%s\" is already used." : "Назва \"%s\" вже використовується.",
    "An empty name is not allowed." : "Порожнє поле не допускається.",
    "Hidden" : "Прихований",
    "Visible" : "Видимий",
    "Automatic" : "Автоматично",
    "Sunday" : "Неділя",
    "Monday" : "Понеділок",
    "Tuesday" : "Вівторок",
    "Wednesday" : "Середа",
    "Thursday" : "Четвер",
    "Friday" : "П'ятниця",
    "Saturday" : "Субота",
    "Add an important item in \"%s\"..." : "Додати важливий пункт в \"%s\"...",
    "Add an item due today in \"%s\"..." : "Додати пункт за сьгодні в \"%s\"...",
    "Add an item in \"%s\"..." : "Додати елемент в \"%s\"...",
    "Add a current item in \"%s\"..." : "Додати поточний елемент в \"%s\"...",
    "Add a subtask to \"%s\"..." : "Додати підзавдання до \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n завершене завданя","%n завершених завдань","%n завершених завдань"],
    "Hours" : "Годин",
    "Minutes" : "Хвилин",
    "Set due date" : "Встановіть термін",
    "%s %% completed" : "%s %% завершено",
    "priority %s: " : "приорітет %s:",
    "high" : "високий",
    "medium" : "середній",
    "low" : "низький",
    "no priority assigned" : "пріоритет на завдано",
    "Remind me" : "Нагадати",
    "at the end" : "в кінці",
    "at the beginning" : "на початку",
    "Set start date" : "Встановити дату початку",
    "Important" : "Важливий",
    "Week" : "Тиждень",
    "All" : "Всі",
    "Current" : "Поточні",
    "Completed" : "Завершені",
    "Delete" : "Видалити",
    "Cancel" : "Скасувати",
    "Edit" : "Редагувати",
    "Link" : "Посилання",
    "Download" : "Завантажити",
    "Save" : "Зберегти",
    "Add List..." : "Додати список...",
    "New List" : "Новий список",
    "Settings" : "Налаштування",
    "Start of week" : "Початок тижня",
    "Visibility of Smart Collections" : "Видимість Smart-колекції",
    "Default" : "За замовчуванням",
    "Load remaining completed tasks." : "Завантажити решту виконаних завдань.",
    "(New category)" : "(Нова категория)",
    "Select categories..." : "Обрати категорії...",
    "Loading the task..." : "Завантаження завдання ...",
    "Task not found!" : "Завдання не знайдене!",
    "add a subtask to" : "додати підзавдання до"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-app-tasks-0.9.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/uk.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Завдання",
    "Due yesterday" : "Вчора",
    "Due today" : "Сьогодні",
    "Due tomorrow" : "Завтра",
    "Due on" : "Термін",
    "Started yesterday" : "Розпочато вчора",
    "Starts today" : "Розпочато сьогодні",
    "Starts tomorrow" : "Розпочнеться завтра",
    "Started on" : "Розпочато",
    "Starts on" : "Починається",
    "[Remind me yesterday at ]HH:mm" : "[Нагадати мені вчора о ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Нагадати мені сьгодні о ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Нагадати мені завтра о ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Нагадати мені ]MMM DD, YYYY,[ о ]HH:mm",
    "Yesterday" : "Вчора",
    "Today" : "Сьогодні",
    "Tomorrow" : "Завтра",
    "in %s" : "в %s",
    "%s ago" : "%s тому",
    "seconds" : "секунд",
    "a minute" : "хвилину",
    "%d minutes" : "%d хвилин",
    "an hour" : "годину",
    "%d hours" : "%d годин",
    "a day" : "день",
    "%d days" : "%d днів",
    "a month" : "місяць",
    "%d months" : "%d місяців",
    "a year" : "рік",
    "%d years" : "%d років",
    "week" : "тиждень",
    "weeks" : "тижнів",
    "day" : "день",
    "days" : "днів",
    "hour" : "година",
    "hours" : "годин",
    "minute" : "хвилина",
    "minutes" : "хвилин",
    "second" : "другий",
    "before beginning" : "до початку",
    "after beginning" : "після початку",
    "before end" : "до кінця",
    "after end" : "після закінчення",
    "Comment" : "Коментар",
    "Add a comment" : "Додати коментар",
    "This will delete the Calendar \"%s\" and all of its entries." : "Це призведе до видалення Календаря \"%s\" і всіх його записів.",
    "The name \"%s\" is already used." : "Назва \"%s\" вже використовується.",
    "An empty name is not allowed." : "Порожнє поле не допускається.",
    "Hidden" : "Прихований",
    "Visible" : "Видимий",
    "Automatic" : "Автоматично",
    "Sunday" : "Неділя",
    "Monday" : "Понеділок",
    "Tuesday" : "Вівторок",
    "Wednesday" : "Середа",
    "Thursday" : "Четвер",
    "Friday" : "П'ятниця",
    "Saturday" : "Субота",
    "Add an important item in \"%s\"..." : "Додати важливий пункт в \"%s\"...",
    "Add an item due today in \"%s\"..." : "Додати пункт за сьгодні в \"%s\"...",
    "Add an item in \"%s\"..." : "Додати елемент в \"%s\"...",
    "Add a current item in \"%s\"..." : "Додати поточний елемент в \"%s\"...",
    "Add a subtask to \"%s\"..." : "Додати підзавдання до \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n завершене завданя","%n завершених завдань","%n завершених завдань","%n завершених завдань"],
    "Hours" : "Годин",
    "Minutes" : "Хвилин",
    "Set due date" : "Встановіть термін",
    "%s %% completed" : "%s %% завершено",
    "priority %s: " : "приорітет %s:",
    "high" : "високий",
    "medium" : "середній",
    "low" : "низький",
    "no priority assigned" : "пріоритет на завдано",
    "Remind me" : "Нагадати",
    "at the end" : "в кінці",
    "at the beginning" : "на початку",
    "Set start date" : "Встановити дату початку",
    "{calendar} shared by {owner}" : "{calendar} надається {owner}",
    "Unnamed" : "Без назви",
    "Important" : "Важливий",
    "Week" : "Тиждень",
    "All" : "Всі",
    "Current" : "Поточні",
    "Completed" : "Завершені",
    "Delete" : "Видалити",
    "Cancel" : "Скасувати",
    "Edit" : "Редагувати",
    "Link" : "Посилання",
    "Download" : "Завантажити",
    "Save" : "Зберегти",
    "Add List..." : "Додати список...",
    "New List" : "Новий список",
    "Settings" : "Налаштування",
    "Start of week" : "Початок тижня",
    "Visibility of Smart Collections" : "Видимість Smart-колекції",
    "Change sort order" : "Зміна порядку сортування",
    "Default" : "За замовчуванням",
    "Due date" : "Термін виконання",
    "Start date" : "Дата початку",
    "Priority" : "Перевага",
    "Alphabetically" : "За алфавітом",
    "Manually" : "Вручну",
    "Load remaining completed tasks." : "Завантажити решту виконаних завдань.",
    "Task is completed" : "Завдання виконано",
    "All day" : "Всі дні",
    "(New category)" : "(Нова категория)",
    "Select categories..." : "Обрати категорії...",
    "Loading the task..." : "Завантаження завдання ...",
    "Task not found!" : "Завдання не знайдене!",
    "add a subtask to" : "додати підзавдання до",
    "Toggle subtasks" : "Перемкнути підзавдання",
    "Toggle completed subtasks" : "Перемкнути завершені підзавдання"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
